#
# spec file for package qmp3gain
#
# Copyright (c) 2024 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


Name:           qmp3gain
Version:        0.9.4
Release:        1699.1.pm.39
Summary:        Qt frontend for mp3gain
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://qmp3gain.sourceforge.io
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  sqlite3
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
Requires:       mp3gain
Supplements:    mp3gain

%description
QMP3Gain is a frontend for mp3gain which analyses and adjusts your
media files so that they have the same volume without the need to
reencode the files.

%lang_package

%prep
%autosetup -p1

%build
export QT_HASH_SEED=0
%qmake5
%make_build

%install
ts='1234567890'
date="`date -u --iso-8601=seconds -d @${ts} | sed 's@+.*@@'`"
TimeStamp="${date}"
LastRegisterTime="${date}.123"
%qmake5_install
install -D -m0644 resources/linux/icons/hicolor/256x256/qmp3gain.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
%suse_update_desktop_file -r %{name} Qt AudioVideo AudioVideoEditing

%find_lang %{name} --with-qt

if pushd %{buildroot}%{_datadir}/%{name}/help
then
 sqlite3 qmp3gain.qhc .dump > dump.old
 sqlite3 qmp3gain.qhc "UPDATE SettingsTable SET Value = '${LastRegisterTime}' WHERE Key = 'LastRegisterTime'"
 sqlite3 qmp3gain.qhc "UPDATE SettingsTable SET Value = ${ts} WHERE Key = 'CreationTime'"
 if grep -qw TimeStampTable dump.old
 then
 sqlite3 qmp3gain.qhc "UPDATE TimeStampTable SET TimeStamp = '${TimeStamp}' WHERE NamespaceId = 1"
 fi
 sqlite3 qmp3gain.qhc .dump > dump.new
 if diff -u dump.old dump.new
 then
  exit 12
 fi
 rm -f dump.old dump.new
 touch -d "@${ts}" * .
fi

%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE.txt
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}/help
%{_datadir}/%{name}/resources

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}/translations

%changelog
* Fri Jan 26 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 0.9.4
  * Feature: Column widths of tableView are stored in config
  * Feature: String columns of tableView got tooltips
  * Fix: Adding file using drag&drop which failed with more dots
    in the filename
  * Fix: Crash due to missing values in case of backend abort
  * Fix: Crash on showing context menu of tableView without any row
- Run spec-cleaner
- Use fdupes macro
* Sun Feb 11 2018 aloisio@gmx.com
- Initial package (0.9.0)
